@@ -153,4 +153,10 @@ creation_options = click.option(
     callback=_cb_key_val,
     help="Driver specific creation options."
          "See the documentation for the selected output driver for "
-         "more information.")
\ No newline at end of file
+         "more information.")
+
+rgb_opt = click.option(
+    '--rgb', 'photometric', 
+    flag_value='rgb',
+    default=False,
+    help="Set RGB photometric interpretation")
